"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _DebuggerService = require("./services/DebuggerService");

var _MemoryUsageLogService = require("./services/MemoryUsageLogService");

var _SystemDataCollector = require("./services/SystemDataCollector");

var _logger = require("./logger");

var _config = _interopRequireDefault(require("./config"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function loadDebuggerService() {
  try {
    return new _DebuggerService.DebuggerService();
  } catch (e) {
    _logger.logger.exception("Error starting location based services", e);
  }
}

function loadMemoryUsageLogService() {
  if (_config.default.MemoryUsageLogService.ENABLED) {
    try {
      _logger.logger.debug('Starting memory usage log service');

      let memoryUsageLogService = new _MemoryUsageLogService.MemoryUsageLogService();
      memoryUsageLogService.start();
      return memoryUsageLogService;
    } catch (e) {
      _logger.logger.exception("Error starting memory usage log service", e);
    }
  }
}

function loadSystemDataCollector() {
  if (_config.default.MonitorConfiguration.ENABLED) {
    try {
      _logger.logger.debug('Starting monitor Service');

      let monitorService = new _SystemDataCollector.SystemDataCollector();
      monitorService.start();
      return monitorService;
    } catch (e) {
      _logger.logger.exception("Error starting monitor service", e);
    }
  }
}

const serviceLoader = [{
  'name': 'DebuggerService',
  'func': loadDebuggerService,
  'location': true
}, {
  'name': 'MemoryUsageLogService',
  'func': loadMemoryUsageLogService,
  'location': false
}, {
  'name': 'MonitorService',
  'func': loadSystemDataCollector,
  'location': false
}];
var _default = serviceLoader;
exports.default = _default;