"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _Namespace = _interopRequireDefault(require("./Namespace"));

var _JSObjectNamespace = _interopRequireWildcard(require("./JSObjectNamespace"));

var _exceptions = require("../../exceptions");

var _ContainerNamespace = _interopRequireDefault(require("./ContainerNamespace"));

var _DebuggerBackchannel = _interopRequireDefault(require("../../services/DebuggerBackchannel"));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const extractor = `(...arguments) => global.__rookout_copy(arguments)`;
process.__rookout_backchannel = new _DebuggerBackchannel.default();
process.__rookout_backchannel.ContainerNamespace = _ContainerNamespace.default;
process.__rookout_backchannel.ObjectNamespace = _JSObjectNamespace.default;

global.__rookout_copy = function copy([index, _this, ...scopes]) {
  const backChannel = process.__rookout_backchannel.get(index);

  backChannel.this = _this;
  backChannel.scopes = scopes;
};

class InspectorFrameNamespace extends _Namespace.default {
  constructor(inspector, frame) {
    super();
    this.inspector = inspector;
    this.frame = frame;
    this.scopes = null;
    this.this = undefined;
    this.position = null;
  }

  readAttribute(name) {
    this.populateScopes();

    if (name === 'this') {
      return new _JSObjectNamespace.default(this.this);
    }

    for (let scope of this.scopes) {
      if (Object.keys(scope).includes(name)) {
        return new _JSObjectNamespace.default(scope[name]);
      }
    }

    throw new _exceptions.RookAttributeNotFound(name);
  }

  callMethod(name, args) {
    switch (name) {
      case "filename":
      case "module":
        return this.filename();

      case "line":
        return this.line();

      case "function":
      case "method":
        return this.function();

      case "locals":
        return this.locals(args);

      case "dump":
        return this.dump(args);

      default:
        return super.callMethod(name, args);
    }
  }

  filename() {
    return new _JSObjectNamespace.default(this.getPosition().filename);
  }

  module() {
    return this.filename();
  }

  line() {
    return new _JSObjectNamespace.default(this.getPosition().line);
  }

  function() {
    return new _JSObjectNamespace.default(this.getPosition().function);
  }

  locals(args) {
    this.populateScopes();
    let result = {};
    let depth = null;
    let dumpConfig = null;

    if (null != args && '' !== args) {
      depth = parseInt(args);

      if (isNaN(depth)) {
        depth = null;
        dumpConfig = _JSObjectNamespace.dumpConfigs[args.toLowerCase()];

        if (dumpConfig === undefined) {
          throw new _exceptions.RookInvalidMethodArguments('locals()', args);
        }
      }
    }

    if (this.scopes !== undefined) {
      for (let i = this.scopes.length - 1; i >= 0; i--) {
        for (let k of Object.keys(this.scopes[i])) {
          result[k] = new _JSObjectNamespace.default(this.scopes[i][k], dumpConfig);

          if (depth !== null && dumpConfig == null) {
            result[k].dumpConfig.maxDepth = depth;
          }
        }
      }
    }

    result.this = new _JSObjectNamespace.default(this.this);
    return new _ContainerNamespace.default(result);
  }

  dump(args) {
    return new _ContainerNamespace.default({
      locals: this.locals(args),
      module: this.module(),
      filename: this.filename(),
      line: this.line(),
      function: this.function()
    });
  }

  getPosition() {
    if (this.position === null) {
      this.position = this.inspector.resolvePosition(this.frame);
    }

    return this.position;
  }

  populateScopes() {
    if (this.scopes !== null) {
      return this.scopes;
    }

    let session = this.inspector;

    let index = process.__rookout_backchannel.add();

    try {
      let context = process.__rookout_backchannel.get(index);

      let scopeChain = this.frame.scopeChain;
      const callArguments = [{
        value: index
      }];
      callArguments.push({
        objectId: this.frame.this.objectId
      });

      for (let scopeId = 0; scopeId < scopeChain.length; scopeId++) {
        let remoteScope = scopeChain[scopeId];
        let nextRemoteScope = scopeChain[scopeId + 1];
        let active = remoteScope.type === 'local' || remoteScope.type === 'catch' || remoteScope.type === 'block' || remoteScope.type === 'closure' && (nextRemoteScope === undefined || nextRemoteScope.type !== 'global');
        if (!active) continue;
        callArguments.push({
          objectId: remoteScope.object.objectId
        });
      }

      let error = null;
      session.post('Runtime.callFunctionOn', {
        objectId: this.frame.scopeChain[0].object.objectId,
        functionDeclaration: extractor,
        arguments: callArguments,
        objectGroup: "backtrace"
      }, e => {
        error = e;
      });

      if (error !== null) {
        throw error;
      }

      this.scopes = context.scopes;
      this.this = context.this;

      if (this.this === global) {
        this.this = undefined;
      }
    } finally {
      process.__rookout_backchannel.delete(index);
    }
  }

}

exports.default = InspectorFrameNamespace;