"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.sanitize = sanitize;
const ROOKOUT_PREFIX = 'ROOKOUT_';
const SANITIZE_BLACKLIST = new Set(['labels']);

function isBlacklisted(optionName, shouldNormalize) {
  if (shouldNormalize) {
    if (optionName.startsWith(ROOKOUT_PREFIX)) {
      optionName = optionName.substring(ROOKOUT_PREFIX.length).toLowerCase();
    } else {
      return true;
    }
  }

  return SANITIZE_BLACKLIST.has(optionName);
}

const reSanitizer = /^[\s"']*|[\s"']*$/g;

function sanitizeIfNecessary(optionName, optionValue) {
  if (!isBlacklisted(optionName) && optionValue != null) {
    return optionValue.replace(reSanitizer, '');
  }

  return optionValue;
}

function sanitize(options, shouldNormalize = false) {
  Object.keys(options).filter(option => !isBlacklisted(option, shouldNormalize) && (typeof options[option] === 'string' || options[option] instanceof String)).forEach(option => options[option] = sanitizeIfNecessary(option, options[option]));
}